@@ -52,6 +52,8 @@ int log_from_time_int = 0;
 /*prototype declaration*/
 int segatex_set_time_real();
 int segatex_set_time_all_real();
+const char* segatex_show_installed_policy();
+void segatex_show_status();
 void segatex_set_time();
 void segatex_set_time_all();
 void segatex_yum_update();
@@ -62,6 +64,87 @@ void segatex_write_to_my_policy();
 void segatex_show_yum_update();
 void segatex_show_interface();
 
+const char* segatex::segatex_show_installed_policy()
+{
+        using namespace std;
+	using namespace boost;
+	const char* installed_policy="";
+
+	const char* policy_targeted = "targeted";
+	const char* policy_strict = "strict";
+	const char* policy_mls = "mls";
+
+	regex policy_targeted_exp(policy_targeted);
+	regex policy_strict_exp(policy_strict);
+	regex policy_mls_exp(policy_mls);
+
+	const char* pol_ro = selinux_policy_root();
+
+	cmatch what;
+	if(regex_search(pol_ro,what,policy_targeted_exp)){
+		installed_policy="targeted";
+	} 
+	if(regex_search(pol_ro,what,policy_strict_exp)){
+		installed_policy="strict";
+	} 
+	if(regex_search(pol_ro,what,policy_mls_exp)){
+		installed_policy="mls";
+	} 
+	return installed_policy;
+}
+
+void segatex::segatex_show_status()
+{
+        using namespace std;
+        const char* filename_sestatus="./segatex_sestatus";
+        ofstream os;
+        os.open(filename_sestatus);
+        if(os){
+                const char* pol_ro = selinux_policy_root();
+                const char* def_tp_pa = selinux_default_type_path();
+                string se_pol_rt_pre = "Your selinux policy root is ";
+                string se_def_tp_pa_pre = "Your selinux default type path is ";
+                string se_pol_rt = pol_ro;
+                string se_pol_rt_end = "You are running SELinux in";
+                int enforce_state = security_getenforce();
+                string en_st = "";
+                if (enforce_state == 1){
+                        en_st = "Enforcing.";
+                }else{
+                        en_st = "Permissive.";
+                }
+		//added for test
+		const char* system_policy=segatex::segatex_show_installed_policy();
+		string system_policy_str=system_policy;
+		//added for test end
+                os << se_pol_rt_pre << endl
+                << se_pol_rt << endl
+                << se_def_tp_pa_pre << endl
+                << def_tp_pa << endl
+                << se_pol_rt_end << endl
+                << en_st <<endl << endl;
+		string en_st_head="";
+		string en_st_tail=""; 
+		if(en_st=="Enforcing."){
+			en_st_head="Which means enforced in ";
+			en_st_tail="-mode."; 
+		}
+		if(en_st=="Permissive."){
+			en_st_head="Which permits any access in ";
+			en_st_tail="-mode."; 
+		}
+		string en_st_echo="";
+		en_st_echo = en_st_head + system_policy_str + en_st_tail;
+		os << en_st_echo << endl;
+                os.close();
+                QFile file( filename_sestatus); // Read the text from a file
+                if ( file.open( IO_ReadOnly ) ) {
+                        QTextStream stream( &file );
+                        textEdit1->setText( stream.read() );
+                }
+        }
+}
+
 void segatex::segatex_remove_my_policy()
 {
         using namespace std;
@@ -223,6 +306,7 @@ void segatex::segatex_yum_update()
 	if(os){
 		FILE *read_fp_install;
 		FILE *read_fp;
+		FILE *read_fp_reload_base_module;
 		#define SIZE_TMP 8600
 		char buffer[SIZE_TMP];
 		int chars_read;
@@ -249,6 +333,20 @@ void segatex::segatex_yum_update()
 			}
 			pclose(read_fp);
 		}
+		const char* installed_policy=segatex::segatex_show_installed_policy();
+		string installed_policy_str=installed_policy;
+		string message_for_reload_base_module_pre= "Reloaded base module from ";
+		string popen_for_reload_base_module_pre= "semodule -b /usr/share/selinux/";
+		string popen_for_reload_base_module_path= "/usr/share/selinux/";
+		string popen_for_reload_base_module_tail= "/base.pp";
+		string message_for_reload_base_module= message_for_reload_base_module_pre + popen_for_reload_base_module_path + installed_policy_str + popen_for_reload_base_module_tail;
+		string popen_for_reload_base_module= popen_for_reload_base_module_pre + installed_policy + popen_for_reload_base_module_tail;
+		const char* please=popen_for_reload_base_module.c_str();
+		read_fp_reload_base_module=popen(please,"r");
+		if(read_fp_reload_base_module != NULL){
+			os << endl << endl << message_for_reload_base_module << endl;
+		}
+		pclose(read_fp_reload_base_module);
 		os.close();
 		QFile file( yum_update_file ); // Read the text from a file
 		if ( file.open( IO_ReadOnly ) ) {
@@ -1534,7 +1632,7 @@ void segatex::segatex_show_interface()
 					p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 					os_policy << "####################################################" << endl;
-					os_policy << "##### This file was generated by segatex2.13" << endl;
+					os_policy << "##### This file was generated by segatex2.14" << endl;
 					os_policy << "####################################################" << endl;
 					os_policy << "module my_policy_by_segatex 1.0.0;" << endl << endl;
 					os_policy << "require {" << endl;
